@@ -1,26 +1,10 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 // View of Journal entries
@@ -38,14 +22,13 @@
 using namespace EventViews;
 
 JournalView::JournalView(QWidget *parent) : EventView(parent)
-    , mChanger(nullptr)
 {
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
-    topLayout->setMargin(0);
+    auto *topLayout = new QVBoxLayout(this);
+    topLayout->setContentsMargins(0, 0, 0, 0);
     mSA = new QScrollArea(this);
     mCurrentWidget = new QWidget(mSA->viewport());
-    QVBoxLayout *mVBoxVBoxLayout = new QVBoxLayout(mCurrentWidget);
-    mVBoxVBoxLayout->setMargin(0);
+    auto *mVBoxVBoxLayout = new QVBoxLayout(mCurrentWidget);
+    mVBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
     mSA->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     mSA->setWidgetResizable(true);
     mSA->setWidget(mCurrentWidget);
@@ -124,9 +107,9 @@ void JournalView::updateView()
     while (it != mEntries.begin()) {
         --it;
         it.value()->clear();
-        const KCalCore::Journal::List journals = calendar()->journals(it.key());
+        const KCalendarCore::Journal::List journals = calendar()->journals(it.key());
         qCDebug(CALENDARVIEW_LOG) << "updateview found" << journals.count();
-        for (const KCalCore::Journal::Ptr &journal : journals) {
+        for (const KCalendarCore::Journal::Ptr &journal : journals) {
             Akonadi::Item item = calendar()->item(journal);
             it.value()->addJournal(item);
         }
@@ -148,9 +131,9 @@ void JournalView::showDates(const QDate &start, const QDate &end, const QDate &)
     }
 
     for (QDate d = end; d >= start; d = d.addDays(-1)) {
-        const KCalCore::Journal::List jnls = calendar()->journals(d);
+        const KCalendarCore::Journal::List jnls = calendar()->journals(d);
         //qCDebug(CALENDARVIEW_LOG) << "Found" << jnls.count() << "journals on date" << d;
-        for (const KCalCore::Journal::Ptr &journal : jnls) {
+        for (const KCalendarCore::Journal::Ptr &journal : jnls) {
             Akonadi::Item item = calendar()->item(journal);
             appendJournal(item, d);
         }
@@ -168,7 +151,7 @@ void JournalView::showIncidences(const Akonadi::Item::List &incidences, const QD
     Q_UNUSED(date);
     clearEntries();
     for (const Akonadi::Item &i : incidences) {
-        if (const KCalCore::Journal::Ptr j = CalendarSupport::journal(i)) {
+        if (const KCalendarCore::Journal::Ptr j = CalendarSupport::journal(i)) {
             appendJournal(i, j->dtStart().date());
         }
     }
@@ -176,7 +159,7 @@ void JournalView::showIncidences(const Akonadi::Item::List &incidences, const QD
 
 void JournalView::changeIncidenceDisplay(const Akonadi::Item &incidence, Akonadi::IncidenceChanger::ChangeType changeType)
 {
-    if (KCalCore::Journal::Ptr journal = CalendarSupport::journal(incidence)) {
+    if (KCalendarCore::Journal::Ptr journal = CalendarSupport::journal(incidence)) {
         switch (changeType) {
         case Akonadi::IncidenceChanger::ChangeTypeCreate:
             appendJournal(incidence, journal->dtStart().date());
